OSMData class

Constructors

OSMData({required int placeId, required String displayName, required double lat, required double lon, AddressModel? address, List<double>? boundingbox})
const
OSMData.fromJson(Map<String, dynamic> json)
factory

Properties

address AddressModel?
final
boundingbox List<double>?
final
displayName String
final
hashCode int
The hash code for this object.
no setteroverride
lat double
final
lon double
final
placeId int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override