PickedData class

Constructors

PickedData({required int placeId, required double lat, required double lon, required LatLong latLong, required String displayName, AddressModel? address})
PickedData.fromJson(Map<String, dynamic> json, LatLong latLong)
factory

Properties

address AddressModel?
final
displayName String
final
hashCode int
The hash code for this object.
no setterinherited
lat double
final
latLong LatLong
final
lon double
final
placeId int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited