RequestService class

Constructors

RequestService()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

convert(Map<String, dynamic> decodedResponse, LatLong center) PickedData
initState(void onNotifyFunction()) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListener() → void
pickData({required double latitude, required double longitude, required String language}) Future<PickedData>
requestLocationName({required double latitude, required double longitude, required String language}) Future<String>
requestSearch({required Client client, required String search, required String language, String? countryFilter}) Future<List<OSMData>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

checkInternet() Future<bool>