AddressModel class
Constructors
- AddressModel({required String city, required String village, required String county, required String state, required String subDistrict, required String country, required String countryCode, required String postCode, String countryName = "", required String locality, required String houseNumber})
-
AddressModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- city → String
-
final
- country ↔ String
-
getter/setter pair
- countryCode → String
-
final
- countryName ↔ String
-
getter/setter pair
- county → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- houseNumber → String
-
final
- locality → String
-
final
- postCode ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → String
-
final
- subDistrict → String
-
final
- village → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited