PickedData class
Constructors
- PickedData({required int placeId, required double lat, required double lon, required LatLong latLong, required String displayName, AddressModel? address})
-
PickedData.fromJson(Map<
String, dynamic> json, LatLong latLong) -
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited